@@ -3,6 +3,7 @@
 """html2text: Turn HTML into equivalent Markdown-structured text."""
 from __future__ import division
 import re
+import sys
 import cgi
 
 try:
@@ -29,7 +30,7 @@ from html2text.utils import (
     skipwrap
 )
 
-__version__ = (2015, 11, 4)
+__version__ = (2016, 4, 2)
 
 
 # TODO:
@@ -44,7 +45,10 @@ class HTML2Text(HTMLParser.HTMLParser):
                  appends lines of text).
             baseurl: base URL of the document we process
         """
-        HTMLParser.HTMLParser.__init__(self)
+        kwargs = {}
+        if sys.version_info >= (3, 4):
+            kwargs['convert_charrefs'] = False
+        HTMLParser.HTMLParser.__init__(self, **kwargs)
 
         # Config options
         self.split_next_td = False
@@ -72,8 +76,6 @@ class HTML2Text(HTMLParser.HTMLParser):
         self.use_automatic_links = config.USE_AUTOMATIC_LINKS  # covered in cli
         self.hide_strikethrough = False  # covered in cli
         self.mark_code = config.MARK_CODE
-        self.single_line_break = config.SINGLE_LINE_BREAK
-        self.use_automatic_links = config.USE_AUTOMATIC_LINKS
         self.wrap_links = config.WRAP_LINKS  # covered in cli
         self.tag_callback = None
 
@@ -306,7 +308,7 @@ class HTML2Text(HTMLParser.HTMLParser):
                 tag_style = element_style(attrs, self.style_def, parent_style)
                 self.tag_stack.append((tag, attrs, tag_style))
             else:
-                dummy, attrs, tag_style = self.tag_stack.pop()
+                dummy, attrs, tag_style = self.tag_stack.pop() if self.tag_stack else (None, {}, {})
                 if self.tag_stack:
                     parent_style = self.tag_stack[-1][2]
 
@@ -367,9 +369,9 @@ class HTML2Text(HTMLParser.HTMLParser):
             self.o(self.strong_mark)
         if tag in ['del', 'strike', 's']:
             if start:
-                self.o("<" + tag + ">")
+                self.o('~~')
             else:
-                self.o("</" + tag + ">")
+                self.o('~~')
 
         if self.google_doc:
             if not self.inheader:
@@ -418,9 +420,9 @@ class HTML2Text(HTMLParser.HTMLParser):
                             try:
                                 title = escape_md(a['title'])
                             except KeyError:
-                                self.o("](" + escape_md(a['href']) + ")")
+                                self.o("](" + escape_md(urlparse.urljoin(self.baseurl, a['href'])) + ")")
                             else:
-                                self.o("](" + escape_md(a['href'])
+                                self.o("](" + escape_md(urlparse.urljoin(self.baseurl, a['href']))
                                        + ' "' + title + '" )')
                         else:
                             i = self.previousIndex(a)
@@ -474,7 +476,7 @@ class HTML2Text(HTMLParser.HTMLParser):
                     self.o("![" + escape_md(alt) + "]")
                     if self.inline_links:
                         href = attrs.get('href') or ''
-                        self.o("(" + escape_md(href) + ")")
+                        self.o("(" + escape_md(urlparse.urljoin(self.baseurl, href)) + ")")
                     else:
                         i = self.previousIndex(attrs)
                         if i is not None:
@@ -512,6 +514,8 @@ class HTML2Text(HTMLParser.HTMLParser):
             else:
                 if self.list:
                     self.list.pop()
+                    if (not self.google_doc) and (not self.list):
+                        self.o('\n')
             self.lastWasList = True
         else:
             self.lastWasList = False
